diff --git a/NEWS b/NEWS
index 730c025329aa9625ec470259cd02f6f5cb1ce5c5..7454933a240c08618e6db399f7fd73e191723bca 100644
--- a/NEWS
+++ b/NEWS
@@ -9,6 +9,8 @@ documents those changes that are of interest to users and admins.
  -- Add new scontrol option: show topology (reports contents of topology.conf 
     file via RPC if topology/tree plugin is configured).
  -- Add advanced reservation display to smap command.
+ -- Replaced remaining references to SLURM_JOBID with SLURM_JOB_ID - except
+    when needed for backwards compatibility.
 
 * Changes in SLURM 1.4.0-pre12
 ==============================
diff --git a/contribs/make.slurm.patch b/contribs/make.slurm.patch
index df23aa7297adceab467fbf5db93c005cbecacfe5..236fae8408d1e912cda5a380150f0862691ba20f 100644
--- a/contribs/make.slurm.patch
+++ b/contribs/make.slurm.patch
@@ -30,7 +30,7 @@ Index: job.c
  child_execute_job (int stdin_fd, int stdout_fd, char **argv, char **envp)
  {
 +/* PARALLEL JOB LAUNCH VIA SLURM */
-+  if (getenv("SLURM_JOBID")) {
++  if (getenv("SLURM_JOB_ID")) {
 +    int i;
 +    static char *argx[128];
 +    argx[0] = "srun";
diff --git a/contribs/mpich1.slurm.patch b/contribs/mpich1.slurm.patch
index 70990087ad17f3842a1d80776d342f6e3829ff4d..c5308d61a8d43b40171113da91563e816d6677e4 100644
--- a/contribs/mpich1.slurm.patch
+++ b/contribs/mpich1.slurm.patch
@@ -76,7 +76,7 @@ Index: mpid/ch_p4/p4/lib/p4_args.c
 +     * for a truly parallel job launch using the existing "execer"
 +     * mode of operation with slight modification.
 +     */
-+    if (getenv("SLURM_JOBID")) {
++    if (getenv("SLURM_JOB_ID")) {
 +	int i;
 +	char *tmp, *hostlist, *host2, *tasks_per_node, *task2;
 +
diff --git a/doc/html/bluegene.shtml b/doc/html/bluegene.shtml
index 265e2b93409fad679c0e26295de4f014beb3267c..d01449dce76230dc98cf42c34644e0f15e677dcf 100644
--- a/doc/html/bluegene.shtml
+++ b/doc/html/bluegene.shtml
@@ -264,7 +264,7 @@ etc.).  Sample prolog and epilog scripts follow. </p>
 #
 # Cancel job to start the termination process for this job
 # and release the bgblock
-/usr/bin/scancel $SLURM_JOBID
+/usr/bin/scancel $SLURM_JOB_ID
 #
 # Wait for bgblock to be released from this job's use
 /usr/sbin/slurm_epilog
diff --git a/doc/html/faq.shtml b/doc/html/faq.shtml
index 5cd9ee95672f0b95d35255cc405eaa578338fcf7..295f1b918f786120262259394ef7deec0f7afb5b 100644
--- a/doc/html/faq.shtml
+++ b/doc/html/faq.shtml
@@ -315,7 +315,7 @@ job allocation?</b></a><br>
 There is a srun option <i>--jobid</i> that can be used to specify 
 a job's ID. 
 For a batch job or within an existing resource allocation, the 
-environment variable <i>SLURM_JOBID</i> has already been defined, 
+environment variable <i>SLURM_JOB_ID</i> has already been defined, 
 so all job steps will run within that job allocation unless 
 otherwise specified.
 The one exception to this is when submitting batch jobs. 
@@ -460,7 +460,7 @@ named <i>_interactive</i>.</p>
 # 
 # Simple batch script that starts SCREEN.
 
-exec screen -Dm -S slurm$SLURM_JOBID
+exec screen -Dm -S slurm$SLURM_JOB_ID
 </pre>
 
 <p>The following script named <i>_interactive_screen</i> is also used.</p>
@@ -1143,7 +1143,7 @@ job ID and allocated hosts for a batch job only.
 if [ X"$SLURM_STEP_ID" = "X" -a X"$SLURM_PROCID" = "X"0 ]
 then
   echo "print =========================================="
-  echo "print SLURM_JOBID = $SLURM_JOBID"
+  echo "print SLURM_JOB_ID = $SLURM_JOB_ID"
   echo "print SLURM_NODELIST = $SLURM_NODELIST"
   echo "print =========================================="
 fi
diff --git a/doc/html/ibm.shtml b/doc/html/ibm.shtml
index 6a22793648f328c92f9b34300c56b2f56b523694..5eb7b6ac1db514154b0fe15ede927fb9aca2a21c 100644
--- a/doc/html/ibm.shtml
+++ b/doc/html/ibm.shtml
@@ -23,7 +23,7 @@ This architecture insures proper operation of all IBM tools.</p>
 This script should contain one or more invocations of poe to launch 
 the tasks.
 If you want to run a job interactively, just execute poe directly. 
-Poe will recognize that it lacks a SLURM job allocation (the SLURM_JOBID 
+Poe will recognize that it lacks a SLURM job allocation (the SLURM_JOB_ID 
 environment variable will be missing) and create the SLURM allocation 
 prior to launching tasks.</p>
 
diff --git a/doc/man/man1/srun.1 b/doc/man/man1/srun.1
index 0ac67179850906de00f0b990845defe0bb9495ba..6e1b2730803e2a2ee577e51de158eb29e0bce57b 100644
--- a/doc/man/man1/srun.1
+++ b/doc/man/man1/srun.1
@@ -397,7 +397,7 @@ is the supplied \fBexecutable\fR program's name.
 \fB\-\-jobid\fR=\fIid\fR
 Initiate a job step under an already allocated job with job id \fIid\fR.
 Using this option will cause \fBsrun\fR to behave exactly as if the
-SLURM_JOBID environment variable was set.
+SLURM_JOB_ID environment variable was set.
 
 .TP
 \fB\-K\fR, \fB\-\-kill\-on\-bad\-exit\fR
@@ -877,7 +877,7 @@ step will begin at node \fIn\fR of the allocated nodelist, where
 the first node is considered node 0.  The \fB\-r\fR option is not 
 permitted along with \fB\-w\fR or \fB\-x\fR, and will be silently
 ignored when not running within a prior allocation (i.e. when
-SLURM_JOBID is not set). The default for \fIn\fR is 0. If the 
+SLURM_JOB_ID is not set). The default for \fIn\fR is 0. If the 
 value of \fB\-\-nodes\fR exceeds the number of nodes identified 
 with the \fB\-\-relative\fR option, a warning message will be 
 printed and the \fB\-\-relative\fR option will take precedence.
@@ -1429,7 +1429,7 @@ Zero origin and comma separated.
 \fBSLURM_JOB_DEPENDENCY\fR
 Set to value of the \-\-dependency option.
 .TP
-\fBSLURM_JOBID\fR
+\fBSLURM_JOB_ID\fR (and \fBSLURM_JOBID\fR for backwards compatibility)
 Job id of the executing job
 
 .TP
@@ -1670,7 +1670,7 @@ the script to be executed follow.
 
 > cat test.sh
 #!/bin/sh
-MACHINEFILE="nodes.$SLURM_JOBID"
+MACHINEFILE="nodes.$SLURM_JOB_ID"
 
 # Generate Machinefile for mpich such that hosts are in the same
 #  order as if run via srun
diff --git a/doc/man/man3/slurm_free_job_info_msg.3 b/doc/man/man3/slurm_free_job_info_msg.3
index d8e23e316ceda3a13884cc1f12a534778165a5b0..e8ec50e9e97012b2d3d45420420c70346e106b9a 100644
--- a/doc/man/man3/slurm_free_job_info_msg.3
+++ b/doc/man/man3/slurm_free_job_info_msg.3
@@ -110,7 +110,7 @@ REM_TIME = ISLURM_GET_REM_TIME(JOBID)
 REM_TIME = ISLURM_GET_REM_TIME2()
 .LP
 ISLURM_GET_REM_TIME2() is equivalent to ISLURM_GET_REM_TIME() except 
-that the JOBID is taken from the SLURM_JOBID environment variable, 
+that the JOBID is taken from the SLURM_JOB_ID environment variable, 
 which is set by SLURM for tasks which it launches.
 Both functions return the number of seconds remaining before the job 
 reaches the end of it's allocated time.
@@ -143,7 +143,7 @@ number into the node information records and the data is terminated with a
 value of \-1. See slurm.h for full details on the data structure's contents. 
 .TP 
 \fIjob_id\fP
-Specifies a slurm job id. If zero, use the SLURM_JOBID environment variable
+Specifies a slurm job id. If zero, use the SLURM_JOB_ID environment variable
 to get the jobid.
 .TP 
 \fIjob_id_ptr\fP
diff --git a/etc/slurm.epilog.clean b/etc/slurm.epilog.clean
index 4ae37ae465198be462561aec8bce51ecd5599914..60df570c6f75bffcbbbd3e9368f1212464db5d61 100644
--- a/etc/slurm.epilog.clean
+++ b/etc/slurm.epilog.clean
@@ -11,7 +11,7 @@
 if [ x$SLURM_UID == "x" ] ; then 
 	exit 0
 fi
-if [ x$SLURM_JOBID == "x" ] ; then 
+if [ x$SLURM_JOB_ID == "x" ] ; then 
         exit 0
 fi
 
@@ -25,7 +25,7 @@ fi
 job_list=`${SLURM_BIN}squeue --noheader --format=%i --user=$SLURM_UID --node=localhost`
 for job_id in $job_list
 do
-	if [ $job_id -ne $SLURM_JOBID ] ; then
+	if [ $job_id -ne $SLURM_JOB_ID ] ; then
 		exit 0
 	fi
 done
diff --git a/src/api/job_info.c b/src/api/job_info.c
index 7b5b5b815e3b1d38cb8ad7530724aec5359eb3ec..0a79e8c22adf9632260e6d9409d677f4c5430c61 100644
--- a/src/api/job_info.c
+++ b/src/api/job_info.c
@@ -767,11 +767,11 @@ extern int32_t islurm_get_rem_time__(uint32_t *jobid)
 extern int32_t islurm_get_rem_time2__()
 {
 	uint32_t jobid;
-	char *slurm_jobid = getenv("SLURM_JOBID");
+	char *slurm_job_id = getenv("SLURM_JOB_ID");
 
-	if (slurm_jobid == NULL)
+	if (slurm_job_id == NULL)
 		return 0;
-	jobid = atol(slurm_jobid);
+	jobid = atol(slurm_job_id);
 	return islurm_get_rem_time__(&jobid);
 }
 
@@ -806,7 +806,7 @@ slurm_get_end_time(uint32_t jobid, time_t *end_time_ptr)
 		if (jobid_env) {
 			jobid = jobid_env;
 		} else {
-			char *env = getenv("SLURM_JOBID");
+			char *env = getenv("SLURM_JOB_ID");
 			if (env) {
 				jobid = (uint32_t) atol(env);
 				jobid_env = jobid;
diff --git a/src/api/pmi.c b/src/api/pmi.c
index c72ee65a70653bca2f5453ad11893ec1dc28310b..549226efa9478fc1ca864fc553656a5d40bf3b2a 100644
--- a/src/api/pmi.c
+++ b/src/api/pmi.c
@@ -185,7 +185,7 @@ int PMI_Init( int *spawned )
 	if (pmi_init)
 		goto replay;
 
-	env = getenv("SLURM_JOBID");
+	env = getenv("SLURM_JOB_ID");
 	if (env)
 		pmi_jobid = atoi(env);
 	else
@@ -446,7 +446,7 @@ int PMI_Get_appnum( int *appnum )
 	if (appnum == NULL)
 		return PMI_ERR_INVALID_ARG;
 
-	env = getenv("SLURM_JOBID");
+	env = getenv("SLURM_JOB_ID");
 	if (env) {
 		*appnum = atoi(env);
 		return PMI_SUCCESS;
diff --git a/src/common/env.c b/src/common/env.c
index 7b0077c594316566bc28cebdbf4236f01086ed3c..ac81deee730a8dddba2e167d12c00637ae085647 100644
--- a/src/common/env.c
+++ b/src/common/env.c
@@ -588,10 +588,16 @@ int setup_env(env_t *env)
 #endif
 	}
 
-	if (env->jobid >= 0
-	    && setenvf(&env->env, "SLURM_JOBID", "%d", env->jobid)) {
-		error("Unable to set SLURM_JOBID environment");
-		rc = SLURM_FAILURE;
+	if (env->jobid >= 0) {
+		if (setenvf(&env->env, "SLURM_JOB_ID", "%d", env->jobid)) {
+			error("Unable to set SLURM_JOB_ID environment");
+			rc = SLURM_FAILURE;
+		}
+		/* and for backwards compatability... */
+		if (setenvf(&env->env, "SLURM_JOBID", "%d", env->jobid)) {
+			error("Unable to set SLURM_JOBID environment");
+			rc = SLURM_FAILURE;
+		}
 	}
 	
 	if (env->nodeid >= 0
diff --git a/src/plugins/select/bluegene/plugin/slurm_epilog.c b/src/plugins/select/bluegene/plugin/slurm_epilog.c
index 2a5bc333078e079430dddc2e5d9f518064dc5bc3..ff85cc4330cbdebfc8d79fb237ba019f272bdb9b 100644
--- a/src/plugins/select/bluegene/plugin/slurm_epilog.c
+++ b/src/plugins/select/bluegene/plugin/slurm_epilog.c
@@ -79,15 +79,15 @@ int main(int argc, char *argv[])
 	char *job_id_char = NULL;
 	uint32_t job_id;
 
-	job_id_char = getenv("SLURM_JOBID");		/* get SLURM job ID */
+	job_id_char = getenv("SLURM_JOB_ID");		/* get SLURM job ID */
 	if (!job_id_char) {
-		fprintf(stderr, "SLURM_JOBID not set\n");
+		fprintf(stderr, "SLURM_JOB_ID not set\n");
 		exit(0);
 	}
 
 	job_id = (uint32_t) atol(job_id_char);
 	if (job_id == 0) {
-		fprintf(stderr, "SLURM_JOBID invalid: %s\n", job_id_char);
+		fprintf(stderr, "SLURM_JOB_ID invalid: %s\n", job_id_char);
 		exit(0);
 	}
 
diff --git a/src/plugins/select/bluegene/plugin/slurm_prolog.c b/src/plugins/select/bluegene/plugin/slurm_prolog.c
index 63fc3f735a84a7f86361c29b6b612fc3836624ff..ef33f4bc7d9082f74b2087b6454b5e24c2e1a76f 100644
--- a/src/plugins/select/bluegene/plugin/slurm_prolog.c
+++ b/src/plugins/select/bluegene/plugin/slurm_prolog.c
@@ -80,15 +80,15 @@ int main(int argc, char *argv[])
 	char *job_id_char = NULL;
 	uint32_t job_id;
 
-	job_id_char = getenv("SLURM_JOBID");		/* get SLURM job ID */
+	job_id_char = getenv("SLURM_JOB_ID");		/* get SLURM job ID */
 	if (!job_id_char) {
-		fprintf(stderr, "SLURM_JOBID not set\n");
+		fprintf(stderr, "SLURM_JOB_ID not set\n");
 		exit(1);				/* abort job */
 	}
 
 	job_id = (uint32_t) atol(job_id_char);
 	if (job_id == 0) {
-		fprintf(stderr, "SLURM_JOBID invalid: %s\n", job_id_char);
+		fprintf(stderr, "SLURM_JOB_ID invalid: %s\n", job_id_char);
 		exit(1);				/* abort job */
 	}
 
diff --git a/src/sbcast/sbcast.c b/src/sbcast/sbcast.c
index e3b461261b26ca8ab86f57c8c5ce5f1f2cea9857..c1e30ba098f318de8a4e253e1e28afc5635cb6ef 100644
--- a/src/sbcast/sbcast.c
+++ b/src/sbcast/sbcast.c
@@ -117,7 +117,7 @@ static void _get_job_info(void)
 	char *jobid_str;
 	uint32_t jobid;
 
-	jobid_str = getenv("SLURM_JOBID");
+	jobid_str = getenv("SLURM_JOB_ID");
 	if (!jobid_str) {
 		error("Command only valid from within SLURM job");
 		exit(1);
diff --git a/src/srun/allocate.h b/src/srun/allocate.h
index 037f9d22cc2aceaf49020d6ff689e079f05c9a2a..79da6884450d1ee48cfe5da3f284600d89ccc039 100644
--- a/src/srun/allocate.h
+++ b/src/srun/allocate.h
@@ -89,21 +89,13 @@ job_desc_msg_t * job_desc_msg_create_from_opts ();
 void job_desc_msg_destroy (job_desc_msg_t *j);
 
 /*
- * Check for SLURM_JOBID environment variable, and if it is a valid
+ * Check for SLURM_JOB_ID environment variable, and if it is a valid
  * jobid, return a pseudo allocation response pointer.
  *
- * Returns NULL if SLURM_JOBID is not present or is invalid.
+ * Returns NULL if SLURM_JOB_ID is not present or is invalid.
  */
 resource_allocation_response_msg_t * existing_allocation(void);
 
-/*
- * Return the jobid number stored in SLURM_JOBID env var
- *
- * Returns 0 if SLURM_JOBID is not set in current environment, or
- * is invalid.
- */
-uint32_t jobid_from_env(void);
-
 /*
  * Create a job step given the job information stored in 'j'
  * After returning, 'j' is filled in with information for job step.
diff --git a/src/srun/opt.c b/src/srun/opt.c
index 30b57d31910084a9ee9d3b0c7f9750e8988358ca..63c9cc10c75a0e23203376874dc3c9841c6a4e07 100644
--- a/src/srun/opt.c
+++ b/src/srun/opt.c
@@ -479,7 +479,7 @@ env_vars_t env_vars[] = {
 {"SLURM_IMMEDIATE",     OPT_INT,        &opt.immediate,     NULL             },
 {"SLURM_JOB_NAME",      OPT_STRING,     &opt.job_name,      
 					&opt.job_name_set_env},
-{"SLURM_JOBID",         OPT_INT,        &opt.jobid,         NULL             },
+{"SLURM_JOB_ID",        OPT_INT,        &opt.jobid,         NULL             },
 {"SLURM_KILL_BAD_EXIT", OPT_INT,        &opt.kill_bad_exit, NULL             },
 {"SLURM_LABELIO",       OPT_INT,        &opt.labelio,       NULL             },
 {"SLURM_LINUX_IMAGE",   OPT_STRING,     &opt.linuximage,    NULL             },
diff --git a/testsuite/expect/test1.12 b/testsuite/expect/test1.12
index d020d2c9f8c3457a76da7ab1ae0005621cbd97a1..8e3ca8137290fe8aa777a067f2b29886d6795b6c 100755
--- a/testsuite/expect/test1.12
+++ b/testsuite/expect/test1.12
@@ -46,7 +46,7 @@ print_header $test_id
 #
 exec $bin_rm -f $file_in
 make_bash_script $file_in "
-  $scontrol show step \$SLURM_JOBID.\$SLURM_STEPID
+  $scontrol show step \$SLURM_JOB_ID.\$SLURM_STEPID
 "
 
 set srun_pid [spawn $srun -N1 -t1 --checkpoint=$ckpt_in $file_in]
diff --git a/testsuite/expect/test1.27 b/testsuite/expect/test1.27
index 00e868621b9ee69a49a1ce2d54569649ea42eea2..50171d9a8acdf1d10c13a9f5601f6baf9dcbeeb5 100755
--- a/testsuite/expect/test1.27
+++ b/testsuite/expect/test1.27
@@ -44,7 +44,7 @@ print_header $test_id
 array set good_vars {
     SLURM_CPUS_ON_NODE 1
     SLURM_CPUS_PER_TASK 1
-    SLURM_JOBID 1
+    SLURM_JOB_ID 1
     SLURM_LAUNCH_NODE_IPADDR 0
     SLURM_LOCALID 0
     SLURM_NNODES 0
diff --git a/testsuite/expect/test11.6 b/testsuite/expect/test11.6
index b69a4bea79287647851333eae008eadc78aff256..0e1bc988f7080375058817a58e6f43157611d56c 100755
--- a/testsuite/expect/test11.6
+++ b/testsuite/expect/test11.6
@@ -59,7 +59,7 @@ if { [string length $partition] == 0 } {
 global env
 set env(CHECKPOINT) "yes"
 make_bash_script $file_in "
-  echo BEGIN=\$SLURM_JOBID
+  echo BEGIN=\$SLURM_JOB_ID
   $bin_sleep 30
   echo FINI
 "
@@ -86,7 +86,7 @@ expect {
 	}
 }
 if {$job_id == 0} {
-	send_user "\nFAILURE: SLURM_JOBID missing\n"
+	send_user "\nFAILURE: SLURM_JOB_ID missing\n"
 	exit 0
 }
 
diff --git a/testsuite/expect/test15.13 b/testsuite/expect/test15.13
index d3884fac3147eaaddd9b803fefe47b7fa29d4d0c..50195ae73fb1cd90dfdfef728f3931f8e528cb88 100755
--- a/testsuite/expect/test15.13
+++ b/testsuite/expect/test15.13
@@ -47,7 +47,7 @@ array set good_vars {
     SLURM_JOB_NODELIST 0
     SLURM_JOB_CPUS_PER_NODE 1
 
-    SLURM_JOBID 1
+    SLURM_JOB_ID 1
     SLURM_NNODES 0
     SLURM_NODELIST 0
     SLURM_TASKS_PER_NODE 1
diff --git a/testsuite/expect/test15.20 b/testsuite/expect/test15.20
index 97221733c6a30a6eb0cf887721b944bff5e38b93..5f1cd3d76dcc30f56ab76054db8c864672c662b5 100755
--- a/testsuite/expect/test15.20
+++ b/testsuite/expect/test15.20
@@ -71,7 +71,7 @@ set salloc_pid [spawn $salloc -N$node_cnt -t1 $srun -l $bin_printenv SLURMD_NODE
 expect {
 	-re "Granted job allocation ($number)" {
 		set job_id $expect_out(1,string)
-		send "$bin_echo MY_ID=\$SLURM_JOBID \n"
+		send "$bin_echo MY_ID=\$SLURM_JOB_ID \n"
 		exp_continue
 	}
 	-re "More processors requested than permitted" {
diff --git a/testsuite/expect/test15.9 b/testsuite/expect/test15.9
index 61c7afc4252f166d63280751f03c26862e9b0c84..71aa3281fa549be24ee1168cfeca2b0001516c9e 100755
--- a/testsuite/expect/test15.9
+++ b/testsuite/expect/test15.9
@@ -41,7 +41,7 @@ print_header $test_id
 
 #
 # Submit a slurm allocate job
-# Interactively print $SLURM_JOBID
+# Interactively print $SLURM_JOB_ID
 #
 set timeout $max_job_delay
 set match 0
@@ -50,14 +50,14 @@ set salloc_pid [spawn $salloc -t1 $bin_bash]
 expect {
 	-re "Granted job allocation ($number)" {
 		set job_id $expect_out(1,string)
-		send "$bin_echo MY_ID=\$SLURM_JOBID \n"
+		send "$bin_echo MY_ID=\$SLURM_JOB_ID \n"
 		array unset expect_out
 		exp_continue
 	}
 	-re "MY_ID=($number)?" {
 		foreach name [array names expect_out] {
 			if {$name == "1,string"} {
-				# SLURM_JOBID is set
+				# SLURM_JOB_ID is set
 				set slurm_jobid $expect_out(1,string)
 				break
 			}
@@ -91,7 +91,7 @@ if { $job_id == 0 } {
 	set exit_code 1
 } else {
 	if { $job_id != $slurm_jobid } {
-		send_user "\nFAILURE: salloc failed to set valid SLURM_JOBID\n"
+		send_user "\nFAILURE: salloc failed to set valid SLURM_JOB_ID\n"
 		set exit_code 1
 	}
 }
diff --git a/testsuite/expect/test2.11 b/testsuite/expect/test2.11
index fc11c44ab94e409918a98f4c35c0fb10d231a887..284da675916db44e18e7dbe6b4dcc07c43d875b2 100755
--- a/testsuite/expect/test2.11
+++ b/testsuite/expect/test2.11
@@ -50,9 +50,9 @@ file delete $file_out
 make_bash_script $file_in "
   $srun $bin_sleep 10 &
   $bin_sleep 1
-  $scontrol listpids \$SLURM_JOBID.10 \$SLURMD_NODENAME
-  $scontrol listpids \$SLURM_JOBID.0 \$SLURMD_NODENAME
-  $scontrol listpids \$SLURM_JOBID \$SLURMD_NODENAME
+  $scontrol listpids \$SLURM_JOB_ID.10 \$SLURMD_NODENAME
+  $scontrol listpids \$SLURM_JOB_ID.0 \$SLURMD_NODENAME
+  $scontrol listpids \$SLURM_JOB_ID \$SLURMD_NODENAME
 "
 
 #
diff --git a/src/srun/allocate.c b/src/srun/allocate.c
index 75994954eed78c1e781e1a3793b3d57685c0759a..a527150eb2f7ff6b45932a4676159f4256474224 100644
--- a/src/srun/allocate.c
+++ b/src/srun/allocate.c
@@ -295,7 +295,7 @@ existing_allocation(void)
                 else
                         error ("Unable to confirm allocation for job %u: %m",
                               old_job_id);
-                info ("Check SLURM_JOBID environment variable "
+                info ("Check SLURM_JOB_ID environment variable "
                       "for expired or invalid job.");
                 exit(1);
         }
@@ -632,7 +632,7 @@ create_job_step(srun_job_t *job, bool use_all_cpus)
 
 	slurm_step_ctx_get(job->step_ctx, SLURM_STEP_CTX_STEPID, &job->stepid);
 	/*  Number of hosts in job may not have been initialized yet if 
 	 *    --jobid was used or only SLURM_JOBID was set in user env.
 	 *    Reset the value here just in case.
 	 */
 	slurm_step_ctx_get(job->step_ctx, SLURM_STEP_CTX_NUM_HOSTS,
@@ -632,7 +632,7 @@ create_job_step(srun_job_t *job, bool use_all_cpus)
 	slurm_step_ctx_get(job->step_ctx, SLURM_STEP_CTX_STEPID, &job->stepid);
 	/*  Number of hosts in job may not have been initialized yet if 
-	 *    --jobid was used or only SLURM_JOBID was set in user env.
+	 *    --jobid was used or only SLURM_JOB_ID was set in user env.
 	 *    Reset the value here just in case.
 	 */